@@ -4,7 +4,7 @@
  *
  * (c)2004 Takuya NISHIMOTO (nishi@hil.t.u-tokyo.ac.jp)
  *
- *  $Id: BehaviorManager.java,v 1.4 2006/12/11 09:09:00 nishi Exp $
+ *  $Id: BehaviorManager.java,v 1.6 2008/02/13 03:47:26 nishi Exp $
  */
 
 package galatea.agent;
@@ -30,7 +30,7 @@ public class BehaviorManager
     private Pattern pattern1_, pattern2_, pattern3_, pattern4_;
 
     private AMBuffer ambuf_;
-    private HashArray /* Agent[] */ agents_ ;
+    private HashArray agents_; // map String => Agent
 
     private long prevTime_;
 
@@ -84,7 +84,7 @@ public class BehaviorManager
             key = "Behavior.Agent." + (i+1);
             String str = Property.getAsStr(key, "woman01 woman01 female01 bg01 1.0");
             // _debugPrint(key + " " + str);
-            List v = Util.makeTokenizedList(str, " ");
+            List<String> v = Util.makeTokenizedList(str, " ");
             double d = Double.parseDouble((String)v.get(4));
             agents_.put
                 ((String)v.get(0), 
@@ -447,7 +447,7 @@ public class BehaviorManager
     {
         prevTime_ = System.currentTimeMillis();
 
-	_send("rep Status.power = ON");
+        _send("rep Status.power = ON");
 
         while (true) {
             _iteration();
