@@ -3,7 +3,7 @@
  * (c)2003 Takuya NISHIMOTO (nishi@hil.t.u-tokyo.ac.jp)
  * Based on Phoenix By Takuya NISHIMOTO and Mitsuhiro KIZU
  *
- * $Id: AddOutItemCommand.java,v 1.4 2007/01/15 03:16:37 nishi Exp $
+ * $Id: AddOutItemCommand.java,v 1.5 2008/02/13 03:47:26 nishi Exp $
  */
 
 package galatea.command;
@@ -15,28 +15,28 @@ import java.util.*;
 public class AddOutItemCommand extends Command
 {
 	
-	private ArrayList items_;
+	private ArrayList<OutItem> items_;
 	
 	public AddOutItemCommand(OutItem oi)
 	{
-		items_ = new ArrayList();
-		items_.add((Object)oi);
+		items_ = new ArrayList<OutItem>();
+		items_.add(oi);
 		// setCondition = "true"
 	}
 	
 	public AddOutItemCommand(OutItem oi, String cond)
 	{
-		items_ = new ArrayList();
-		items_.add((Object)oi);
+		items_ = new ArrayList<OutItem>();
+		items_.add(oi);
 		setCondition(cond);
 	}
 	
-	public AddOutItemCommand(ArrayList items)
+	public AddOutItemCommand(ArrayList<OutItem> items)
 	{
 		items_ = items;
 	}
 	
-	public AddOutItemCommand(ArrayList items, String cond)
+	public AddOutItemCommand(ArrayList<OutItem> items, String cond)
 	{
 		items_ = items;
 		setCondition(cond);
