@@ -3,7 +3,7 @@
  * (c)2003 Takuya NISHIMOTO (nishi@hil.t.u-tokyo.ac.jp)
  * Based on Phoenix By Takuya NISHIMOTO and Mitsuhiro KIZU
  *
- * $Id: EndCommand.java,v 1.2 2006/11/20 01:13:35 nishi Exp $
+ * $Id: EndCommand.java,v 1.3 2007/08/09 02:31:03 nishi Exp $
  */
 
 package galatea.command;
@@ -16,17 +16,21 @@ public class EndCommand extends Command
 	
 	boolean now_;
 	String next_;
+	String post_;
 	
 	public EndCommand(boolean now)
 	{
 		now_ = now;
+		setCondition("true");
+		post_ = "";
 	}
 	
-	public EndCommand(String next, String cond)
+	public EndCommand(String next)
 	{
 		next_ = next;
-		setCondition(cond);
+		setCondition("true");
 		now_ = false;
+		post_ = "";
 	}
 	
 	public EndCommand(String next, String cond, boolean now)
@@ -34,6 +38,15 @@ public class EndCommand extends Command
 		next_ = next;
 		setCondition(cond);
 		now_ = now;
+		post_ = "";
+	}
+	
+	public EndCommand(String next, String cond, boolean now, String post)
+	{
+		next_ = next;
+		setCondition(cond);
+		now_ = now;
+		post_ = post;
 	}
 	
 	public EndCommand()
@@ -54,6 +67,7 @@ public class EndCommand extends Command
 			s += " cond=\"" + getConditionAsEncodedString() + "\"";
 		}
 		s += " now=\"" + now_ +"\"";
+		s += " post=\"" + post_ +"\"";
 		if ( next_ != null && next_.length() > 0 ) {
 			s += ">" + Util.encodeXmlChars(next_) + "</end>";
 		} else {
@@ -69,7 +83,8 @@ public class EndCommand extends Command
 		interpreterContext_.setEndImm(now_);
 		if ( next_ != null ) {
 			String nf = ecmascript_.evaluate(next_);
-			interpreterContext_.setNextDocFile(nf);
+			String ps = ecmascript_.evaluate(post_);
+			interpreterContext_.setNextDocFile(nf, ps);
 		}
 	}
 	
