@@ -1,7 +1,7 @@
 /*
  * Galatea Dialog Manager:
  * (c)2003 Takuya NISHIMOTO (nishi@hil.t.u-tokyo.ac.jp)
- * $Id: IC.java,v 1.48 2007/01/22 05:42:37 nishi Exp $
+ * $Id: IC.java,v 1.52 2008/02/14 02:00:07 nishi Exp $
  */
 
 package galatea.dialog;
@@ -20,13 +20,13 @@ import galatea.io.DeviceManager;
 import galatea.io.IOutputEventListener;
 import galatea.io.OutItemQueueManager;
 import galatea.io.OutputEventQueueManager;
+import galatea.logger.Logger;
 import galatea.outitem.OutItem;
 import galatea.outitem.VoiceOutItem;
 import galatea.relaxer.event.EventEv;
 import galatea.relaxer.event.EventInterpreted;
 import galatea.relaxer.event.IEventEvChoice;
 import galatea.scripting.ECMAScript;
-import galatea.util.Logger;
 import galatea.util.StringHashArray;
 import galatea.util.Util;
 
@@ -45,7 +45,10 @@ implements IInteractionController
 	{
 	
 	private Logger dbg = new Logger("IC");
+
 	private String nextDocFile_ = "";
+	private String postString_ = "";
+	
 	private ContentState currState_ = null;
 	private OutItemQueueManager outQueueManager_ = null;
 	private InterpretedEventQueueManager interpretedEventQueueManager_ = null;
@@ -54,14 +57,16 @@ implements IInteractionController
 	private DeviceManager deviceManager_;
 	private StateMap stateMap_ = null;
 	private ControllerMode imode_ = new ControllerMode();
-	private ArrayList commands_ = null;
-	private ArrayList debuggerEvals_ = null;
+	private ArrayList<Command> commands_ = null;
+	private ArrayList<String> debuggerEvals_ = null;
 
 	private void _updateDialogStateChange(String state) {
 		deviceManager_.updateDialogStateChange(state);
 	}
 	
-	private ArrayList httpAsyncResponseListeners_ = new ArrayList();
+	private ArrayList<IHttpAsyncResponseListener> 
+		httpAsyncResponseListeners_ 
+		= new ArrayList<IHttpAsyncResponseListener>();
 	public void addHttpAsyncResponseListener(IHttpAsyncResponseListener listener) {
 		httpAsyncResponseListeners_.add(listener);
 	}
@@ -77,6 +82,7 @@ implements IInteractionController
 	}
 	
 	private String evalAfterInputHandler_ = null;
+	
 	private synchronized void _resetEvalAfterInputHandler() {
 		evalAfterInputHandler_ = null;
 	}
@@ -92,7 +98,7 @@ implements IInteractionController
 			try {
 				ecmascript_.evaluate( evalAfterInputHandler_ );
 			} catch (RuntimeError e) {
-				dbg.print(e.toString());
+				dbg.print("IC: evaluate " + e.toString());
 			}
 			dbg.print("IC: afterInputHandler: "+evalAfterInputHandler_);
 		}
@@ -105,7 +111,7 @@ implements IInteractionController
 		dbg.print("IC: constructor start");
 		try {
 			ecmascript_ = new ECMAScript();
-			dbg.print(ecmascript_.getVersion());
+			// dbg.print(ecmascript_.getVersion());
 		} catch (RuntimeError e) {
 			dbg.print(e.toString());
 		}
@@ -114,17 +120,22 @@ implements IInteractionController
 		deviceManager_ = new DeviceManager();
 		
 		outQueueManager_ = new OutItemQueueManager(deviceManager_);
-		commands_ = new ArrayList();  // ArrayList<Command>
+		commands_ = new ArrayList<Command>();  
 		imode_ = new ControllerMode();
-		debuggerEvals_ = new ArrayList();  // ArrayList<String>
+		debuggerEvals_ = new ArrayList<String>();
 
 		dbg.print("IC: constructor end");
 	}
 	
 	public void start() {
+		//System.err.println(ecmascript_.getVersionAndCopyright());
 		deviceManager_.start(this, this, this, this, this);
 	}
 	
+	public String getScriptVersionAndCopyright() {
+		return ecmascript_.getVersionAndCopyright();
+	}
+	
 	public boolean waitDevicesForReady() {
 		return deviceManager_.waitDevicesForReady();
 	}
@@ -269,7 +280,7 @@ implements IInteractionController
 				// stopOutput();
 				dbg.print(ev.toString());
 			} else if (ev.equals("start-doc")) {
-				setNextDocFile(arg);
+				setNextDocFile(arg, "");
 				dbg.print(ev.toString());
 			} else if (ev.equals("quit-doc")) {
 				terminateDialogAction();
@@ -402,7 +413,7 @@ implements IInteractionController
 	public void setNextDocumentAction(String uri) {
 		if (uri != null && uri.length() > 0 ) {
 			dbg.print("IC: setNextDocumentAction " + uri);
-			setNextDocFile(uri);
+			setNextDocFile(uri, "");
 		}
 	}
 	
@@ -447,7 +458,7 @@ implements IInteractionController
 		resetNextState();
 		setEndFlag(true);
 		setEndImm(true);
-		setNextDocFile("");
+		setNextDocFile("", "");
 	}
 	
 	
@@ -490,7 +501,7 @@ implements IInteractionController
 	
 	// implements AbstractIC for command.*
 	// this method is used from CompositeCommand
-	public void insertCommandsTop(ArrayList v) {
+	public void insertCommandsTop(ArrayList<Command> v) {
 		if ( commands_ == null ) return;
 		dbg.print("IC: insertCommandsTop " + Util.removeNewLines(v.toString()));
 		commands_.addAll(0, v);
@@ -505,9 +516,10 @@ implements IInteractionController
 	
 	// implements AbstractIC for command.*
 	// this method is used from EndCommand 
-	public void setNextDocFile(String s) {
-		dbg.print("IC: setNextDocFile:"+s);
-		nextDocFile_ = s;
+	public void setNextDocFile(String nextfile, String post) {
+		dbg.print("IC: setNextDocFile:"+nextfile+" post:"+post);
+		nextDocFile_ = nextfile;
+		postString_ = post;
 	}
 	
 	/**
@@ -517,11 +529,16 @@ implements IInteractionController
 		return nextDocFile_;
 	}
 	
+	public String getPostString() {
+		return postString_;
+	}
+
 	/**
 	 * IInteractionController
 	 */
 	public void resetNextDocFile() 	{ 
 		nextDocFile_ = "";
+		postString_ = "";
 	}
 	
 	// implements AbstractIC for command.*
