@@ -2,7 +2,7 @@
  * Galatea Dialog Manager:
  * (c)2004 Takuya NISHIMOTO (nishi@hil.t.u-tokyo.ac.jp)
  *
- * $Id: DialogManagerWindow.java,v 1.11 2007/01/22 05:42:37 nishi Exp $
+ * $Id: DialogManagerWindow.java,v 1.18 2008/02/14 03:35:54 nishi Exp $
  */
 
 /*
@@ -26,9 +26,13 @@ package galatea.dialog.window;
 import galatea.dialog.ISystemEventLogger;
 import galatea.dialog.Tstamp;
 import galatea.document.DocLoader;
+import galatea.httpclient.INetUtilListener;
+import galatea.httpclient.NetUtil;
+import galatea.logger.ILoggerListener;
 import galatea.util.Property;
 import galatea.util.Util;
 
+import java.awt.Component;
 import java.awt.GridBagConstraints;
 import java.awt.GridBagLayout;
 import java.awt.Insets;
@@ -51,15 +55,182 @@ import javax.swing.JTabbedPane;
 import javax.swing.JTextArea;
 import javax.swing.JTextField;
 import javax.swing.KeyStroke;
+import javax.swing.LookAndFeel;
 import javax.swing.ScrollPaneConstants;
 import javax.swing.SwingConstants;
 import javax.swing.SwingUtilities;
+import javax.swing.UIManager;
 import javax.swing.event.HyperlinkEvent;
 import javax.swing.event.HyperlinkListener;
 
 public class DialogManagerWindow
-	implements ISystemEventLogger
+	implements ISystemEventLogger, INetUtilListener, ILoggerListener
 {
+	private final class MenuExitActionListener implements ActionListener {
+		public void actionPerformed(ActionEvent e) {
+			System.exit(0);
+		}
+	}
+
+	private final class MenuQuitActionListener implements ActionListener {
+		public void actionPerformed(ActionEvent e) {
+			if (eventListener_ != null) {
+				eventListener_.quitAction();
+			} else {
+				System.out.println(e);
+			}
+		}
+	}
+
+	private final class MainPanelButtonStopActionListener implements
+			ActionListener {
+		public void actionPerformed(ActionEvent e) {
+			labelPauseMode_.setText("Mode: Pause");
+			if (eventListener_ != null) {
+				eventListener_.setPauseModeAction(true);
+			} else {
+				System.out.println(e);
+			}
+		}
+	}
+
+	private final class MainPanelButtonStartActionListener implements
+			ActionListener {
+		public void actionPerformed(ActionEvent e) {
+			labelPauseMode_.setText("Mode: Run");
+			if (eventListener_ != null) {
+				eventListener_.setPauseModeAction(false);
+			} else {
+				System.out.println(e);
+			}
+		}
+	}
+
+	private final class MainPanelValidateActionListener implements ActionListener {
+		public void actionPerformed(ActionEvent e) {
+			String uri = textFieldLocation_.getText();
+			if (uri != null && uri.length() > 0) {
+				String doc = DocLoader.convert(uri);
+				if (doc != "") {
+					System.err.println("[DM Validate OK] " + uri);
+				} else {
+					System.err.println("[DM Validate ERROR] " + uri);
+				}
+			}
+		}
+	}
+
+	private final class MainPanelGoActionListener implements ActionListener {
+		public void actionPerformed(ActionEvent e) {
+			String uri = textFieldLocation_.getText();
+			if (eventListener_ != null) {
+				labelPauseMode_.setText("Mode: Run");
+				eventListener_.setPauseModeAction(false);
+				eventListener_.setNextDocumentAction(uri);
+				eventListener_.terminateDialogAction();
+			} else {
+				System.out.println(e);
+				System.out.println(uri);
+			}
+		}
+	}
+
+//	private final class MenuViewGrammarActionListener implements ActionListener {
+//		public void actionPerformed(ActionEvent e) {
+//			if (viewGrammarFrame_ == null) {
+//				viewGrammarFrame_ = new JFrame("View Grammar");
+//				viewGrammarPane_ = new JEditorPane("text/plain", "");
+//				viewGrammarPane_.setEditable(false);
+//				viewGrammarPane_.setText(grammarFile_);
+//				viewGrammarFrame_.getContentPane().add(new JScrollPane
+//						(viewGrammarPane_,
+//								ScrollPaneConstants.VERTICAL_SCROLLBAR_ALWAYS,
+//								ScrollPaneConstants.HORIZONTAL_SCROLLBAR_ALWAYS
+//						));
+//				viewGrammarFrame_.setSize(600, 400);
+//				viewGrammarFrame_.setVisible(true);
+//				viewGrammarFrame_.setDefaultCloseOperation(JFrame.HIDE_ON_CLOSE);
+//			} else {
+//				viewGrammarFrame_.setVisible(true);
+//			}
+//		}
+//	}
+//
+//	private final class MenuViewTranslatedActionListener implements ActionListener {
+//		public void actionPerformed(ActionEvent e) {
+//			if (viewTranslatedFrame_ == null) {
+//				viewTranslatedFrame_ = new JFrame("View Translated");
+//				
+//				viewTranslatedPane_ = new JEditorPane("text/plain", "");
+//				viewTranslatedPane_.setEditable(false);
+//				viewTranslatedPane_.setText(translatedFile_);
+//				
+//				viewTranslatedFrame_.getContentPane().add(new JScrollPane
+//						(viewTranslatedPane_,
+//								ScrollPaneConstants.VERTICAL_SCROLLBAR_ALWAYS,
+//								ScrollPaneConstants.HORIZONTAL_SCROLLBAR_ALWAYS
+//						));
+//				
+//				viewTranslatedFrame_.setSize(600, 400);
+//				viewTranslatedFrame_.setVisible(true);
+//				viewTranslatedFrame_.setDefaultCloseOperation(JFrame.HIDE_ON_CLOSE);
+//				
+//			} else {
+//				viewTranslatedFrame_.setVisible(true);
+//			}
+//		}
+//	}
+
+//	private final class MenuViewSrcActionListener implements ActionListener {
+//		public void actionPerformed(ActionEvent e) {
+//			if (viewSrcFrame_ == null) {
+//				viewSrcFrame_ = new JFrame("View Source");
+//				
+//				viewSrcPane_ = new JEditorPane("text/plain", "");
+//				viewSrcPane_.setEditable(false);
+//				viewSrcPane_.setText(srcFile_);
+//				
+//				viewSrcFrame_.getContentPane().add(new JScrollPane
+//						(viewSrcPane_,
+//								ScrollPaneConstants.VERTICAL_SCROLLBAR_ALWAYS,
+//								ScrollPaneConstants.HORIZONTAL_SCROLLBAR_ALWAYS
+//						));
+//				
+//				viewSrcFrame_.setSize(600, 400);
+//				viewSrcFrame_.setVisible(true);
+//				viewSrcFrame_.setDefaultCloseOperation(JFrame.HIDE_ON_CLOSE);
+//				
+//			} else {
+//				viewSrcFrame_.setVisible(true);
+//			}
+//		}
+//	}
+
+	private final class MenuOpenActionListener implements ActionListener {
+		public void actionPerformed(ActionEvent e) {
+			// currDirPath_ = "file:C:/workspace/galatea/../"
+			String org = currLocalDirPath_.replaceFirst("file:", "");
+			JFileChooser chooser = new JFileChooser(org); 
+			chooser.showOpenDialog(null);
+			File file = chooser.getSelectedFile();
+			if ( file == null ) return;
+			String uri = file.getAbsolutePath();
+			uri = Util.replaceAll(uri, "\\", "/");
+			uri = "file:" + uri;
+			if (eventListener_ != null) {
+				labelPauseMode_.setText("Mode: Run");
+				eventListener_.setPauseModeAction(false);
+				eventListener_.setNextDocumentAction(uri);
+				eventListener_.terminateDialogAction();
+			} else {
+				System.out.println(e);
+				System.out.println(uri);
+			}
+			//
+			currLocalDirPath_ = Util.getUriDirectory(uri);
+		}
+	}
+
 	private JEditorPane  applogPane_ = null;
 	private StringBuffer applogContent_ = null;
 	
@@ -75,22 +246,22 @@ public class DialogManagerWindow
 	private JTextField textFieldLocation_ = null;
 	private JTextArea textFieldSpeaking_ = null;
 	
-	private String currDirPath_ = "";
+	private String currLocalDirPath_ = "";
 	
 	//
-	private JFrame viewSrcFrame_ = null;
-	private JEditorPane viewSrcPane_ = null;
-	private String srcFile_ = "";
+	//private JFrame viewSrcFrame_ = null;
+	//private JEditorPane viewSrcPane_ = null;
+	//private String srcFile_ = "";
 	
 	//
-	private JFrame viewTranslatedFrame_ = null;
-	private JEditorPane viewTranslatedPane_ = null;
-	private String translatedFile_ = "";
+	//private JFrame viewTranslatedFrame_ = null;
+	//private JEditorPane viewTranslatedPane_ = null;
+	//private String translatedFile_ = "";
 	
 	//
-	private JFrame viewGrammarFrame_ = null;
-	private JEditorPane viewGrammarPane_ = null;
-	private String grammarFile_ = "";
+	//private JFrame viewGrammarFrame_ = null;
+	//private JEditorPane viewGrammarPane_ = null;
+	//private String grammarFile_ = "";
 	
 	private String test1Label_;
 	private String test1Command_;
@@ -111,20 +282,46 @@ public class DialogManagerWindow
 	private JTextField textFieldDebuggerEval_;
 	private JTextArea textFieldDebuggerResult_;
 	private StringBuffer debugEvalResultContent_;
-	
-//	private JTextField textFieldHttpService_;
-//	private JEditorPane httpServiceEditorPane_;
-	
+
+	private JTextArea textFieldHttpLog_;
+	private String httpLogText_ = "";
+	private JTextArea textFieldViewSrc_;
+	private JTextArea textFieldViewGram_;
+	private JTextArea textFieldViewTrans_;
+	private JTextArea textFieldLogger_;
+	private String loggerText_ = "";
+	private JTextArea textFieldConfig_;
 	
 	private void _send(String str) {
 		System.out.println(str);
 		System.out.flush();
 	}
 	
-	private void _makeWindow() throws Exception {
+	private void _makeWindow(int width, int height) throws Exception {
 		JFrame frame = new JFrame(galatea.dialog.Tstamp.TSTAMP);
 		frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
 		
+		JMenuBar menuBar = _makeMenuBar();
+		frame.setJMenuBar(menuBar);
+		
+		JTabbedPane tab = new JTabbedPane();
+		tab.addTab("Main", _makeMainPanel());
+		tab.addTab("Config", _makeConfigPanel());
+		tab.addTab("Script", _makeDebuggerPanel());
+		tab.addTab("Logger", _makeLoggerPanel());
+		tab.addTab("Http", _makeHttpPanel());
+		tab.addTab("Source", _makeViewSrcPanel());
+		tab.addTab("Translated", _makeViewTransPanel());
+		tab.addTab("Grammar", _makeViewGramPanel());
+		tab.setTabLayoutPolicy(JTabbedPane.SCROLL_TAB_LAYOUT);
+		tab.setTabPlacement(SwingConstants.TOP);
+		frame.getContentPane().add(tab);
+		
+		frame.setSize(width, height);
+		frame.setVisible(true);
+	}
+
+	private JMenuBar _makeMenuBar() {
 		// menu bar
 		JMenuBar menuBar = new JMenuBar();
 		JMenu menuFile = new JMenu("File");
@@ -133,130 +330,32 @@ public class DialogManagerWindow
 		// File
 		JMenuItem itemOpen = new JMenuItem("Open Local File...");
 		menuFile.add(itemOpen);
-		itemOpen.addActionListener( new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				JFileChooser chooser = new JFileChooser(currDirPath_);
-				chooser.showOpenDialog(null);
-				File file = chooser.getSelectedFile();
-				if ( file == null ) return;
-				String uri = file.getAbsolutePath();
-				uri = Util.replaceAll(uri, "\\", "/");
-				uri = "file:" + uri;
-				if (eventListener_ != null) {
-					labelPauseMode_.setText("Mode: Run");
-					eventListener_.setPauseModeAction(false);
-					eventListener_.setNextDocumentAction(uri);
-					eventListener_.terminateDialogAction();
-				} else {
-					System.out.println(e);
-					System.out.println(uri);
-				}
-			}
-		});
+		itemOpen.addActionListener( new MenuOpenActionListener());
 		
 		//
-		JMenuItem itemViewSrc = new JMenuItem("View Source");
-		menuFile.add(itemViewSrc);
-		itemViewSrc.addActionListener( new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				if (viewSrcFrame_ == null) {
-					viewSrcFrame_ = new JFrame("View Source");
-					
-					viewSrcPane_ = new JEditorPane("text/plain", "");
-					viewSrcPane_.setEditable(false);
-					viewSrcPane_.setText(srcFile_);
-					
-					viewSrcFrame_.getContentPane().add(new JScrollPane
-							(viewSrcPane_,
-									ScrollPaneConstants.VERTICAL_SCROLLBAR_ALWAYS,
-									ScrollPaneConstants.HORIZONTAL_SCROLLBAR_ALWAYS
-							));
-					
-					viewSrcFrame_.setSize(600, 400);
-					viewSrcFrame_.setVisible(true);
-					viewSrcFrame_.setDefaultCloseOperation(JFrame.HIDE_ON_CLOSE);
-					
-				} else {
-					viewSrcFrame_.setVisible(true);
-				}
-			}
-		});
-		
+//		JMenuItem itemViewSrc = new JMenuItem("View Source");
+//		menuFile.add(itemViewSrc);
+//		itemViewSrc.addActionListener( new MenuViewSrcActionListener());
 		
 		//
-		JMenuItem itemViewTranslated = new JMenuItem("View Translated");
-		menuFile.add(itemViewTranslated);
-		itemViewTranslated.addActionListener( new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				if (viewTranslatedFrame_ == null) {
-					viewTranslatedFrame_ = new JFrame("View Translated");
-					
-					viewTranslatedPane_ = new JEditorPane("text/plain", "");
-					viewTranslatedPane_.setEditable(false);
-					viewTranslatedPane_.setText(translatedFile_);
-					
-					viewTranslatedFrame_.getContentPane().add(new JScrollPane
-							(viewTranslatedPane_,
-									ScrollPaneConstants.VERTICAL_SCROLLBAR_ALWAYS,
-									ScrollPaneConstants.HORIZONTAL_SCROLLBAR_ALWAYS
-							));
-					
-					viewTranslatedFrame_.setSize(600, 400);
-					viewTranslatedFrame_.setVisible(true);
-					viewTranslatedFrame_.setDefaultCloseOperation(JFrame.HIDE_ON_CLOSE);
-					
-				} else {
-					viewTranslatedFrame_.setVisible(true);
-				}
-			}
-		});
+//		JMenuItem itemViewTranslated = new JMenuItem("View Translated");
+//		menuFile.add(itemViewTranslated);
+//		itemViewTranslated.addActionListener( new MenuViewTranslatedActionListener());
 		
 		//
-		JMenuItem itemViewGrammar = new JMenuItem("View Grammar");
-		menuFile.add(itemViewGrammar);
-		itemViewGrammar.addActionListener( new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				if (viewGrammarFrame_ == null) {
-					viewGrammarFrame_ = new JFrame("View Grammar");
-					viewGrammarPane_ = new JEditorPane("text/plain", "");
-					viewGrammarPane_.setEditable(false);
-					viewGrammarPane_.setText(grammarFile_);
-					viewGrammarFrame_.getContentPane().add(new JScrollPane
-							(viewGrammarPane_,
-									ScrollPaneConstants.VERTICAL_SCROLLBAR_ALWAYS,
-									ScrollPaneConstants.HORIZONTAL_SCROLLBAR_ALWAYS
-							));
-					viewGrammarFrame_.setSize(600, 400);
-					viewGrammarFrame_.setVisible(true);
-					viewGrammarFrame_.setDefaultCloseOperation(JFrame.HIDE_ON_CLOSE);
-				} else {
-					viewGrammarFrame_.setVisible(true);
-				}
-			}
-		});
-		
+//		JMenuItem itemViewGrammar = new JMenuItem("View Grammar");
+//		menuFile.add(itemViewGrammar);
+//		itemViewGrammar.addActionListener( new MenuViewGrammarActionListener());
 		
 		//
 		JMenuItem itemQuit = new JMenuItem("Quit Current Dialog");
 		menuFile.add(itemQuit);
-		itemQuit.addActionListener( new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				if (eventListener_ != null) {
-					eventListener_.quitAction();
-				} else {
-					System.out.println(e);
-				}
-			}
-		});
+		itemQuit.addActionListener( new MenuQuitActionListener());
 		
 		//
 		JMenuItem itemExit = new JMenuItem("Exit");
 		menuFile.add(itemExit);
-		itemExit.addActionListener( new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				System.exit(0);
-			}
-		});
+		itemExit.addActionListener( new MenuExitActionListener());
 		
 		// Face
 		JMenu menuFace = new JMenu("Face");
@@ -523,7 +622,7 @@ public class DialogManagerWindow
 			menuDemo.add(itemDemo1);
 			itemDemo1.addActionListener( new ActionListener() {
 				public void actionPerformed(ActionEvent e) {
-					String adrs = Util.resolveAdrs(currDirPath_, demo1File_);
+					String adrs = Util.resolveAdrs(currLocalDirPath_, demo1File_);
 					if (eventListener_ != null) {
 						labelPauseMode_.setText("Mode: Run");
 						eventListener_.setPauseModeAction(false);
@@ -543,7 +642,7 @@ public class DialogManagerWindow
 			menuDemo.add(itemDemo2);
 			itemDemo2.addActionListener( new ActionListener() {
 				public void actionPerformed(ActionEvent e) {
-					String adrs = Util.resolveAdrs(currDirPath_, demo2File_);
+					String adrs = Util.resolveAdrs(currLocalDirPath_, demo2File_);
 					if (eventListener_ != null) {
 						labelPauseMode_.setText("Mode: Run");
 						eventListener_.setPauseModeAction(false);
@@ -563,7 +662,7 @@ public class DialogManagerWindow
 			menuDemo.add(itemDemo3);
 			itemDemo3.addActionListener( new ActionListener() {
 				public void actionPerformed(ActionEvent e) {
-					String adrs = Util.resolveAdrs(currDirPath_, demo3File_);
+					String adrs = Util.resolveAdrs(currLocalDirPath_, demo3File_);
 					if (eventListener_ != null) {
 						labelPauseMode_.setText("Mode: Run");
 						eventListener_.setPauseModeAction(false);
@@ -583,7 +682,7 @@ public class DialogManagerWindow
 			menuDemo.add(itemDemo4);
 			itemDemo4.addActionListener( new ActionListener() {
 				public void actionPerformed(ActionEvent e) {
-					String adrs = Util.resolveAdrs(currDirPath_, demo4File_);
+					String adrs = Util.resolveAdrs(currLocalDirPath_, demo4File_);
 					if (eventListener_ != null) {
 						labelPauseMode_.setText("Mode: Run");
 						eventListener_.setPauseModeAction(false);
@@ -595,20 +694,7 @@ public class DialogManagerWindow
 				}
 			});
 		}
-		
-		// end of menuBar
-		frame.setJMenuBar(menuBar);
-		
-		JTabbedPane tab = new JTabbedPane();
-		tab.addTab("Main", _makeMainPanel());
-		tab.addTab("Debugger", _makeDebuggerPanel());
-//		tab.addTab("HttpService", _makeHttpServicePanel());
-		tab.setTabLayoutPolicy(JTabbedPane.SCROLL_TAB_LAYOUT);
-		tab.setTabPlacement(SwingConstants.TOP);
-		frame.getContentPane().add(tab);
-		
-		frame.setSize(600, 400);
-		frame.setVisible(true);
+		return menuBar;
 	}
 	
 	
@@ -659,69 +745,26 @@ public class DialogManagerWindow
 		_setPos(c, 2, 1);
 		JButton buttonGo = new JButton("Go"); 
 		panel.add(buttonGo, c);
-		buttonGo.addActionListener( new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				String uri = textFieldLocation_.getText();
-				if (eventListener_ != null) {
-					labelPauseMode_.setText("Mode: Run");
-					eventListener_.setPauseModeAction(false);
-					eventListener_.setNextDocumentAction(uri);
-					eventListener_.terminateDialogAction();
-				} else {
-					System.out.println(e);
-					System.out.println(uri);
-				}
-			}
-		});
+		buttonGo.addActionListener( new MainPanelGoActionListener());
 		
 		// ---* button 
 		_setPos(c, 3, 1);
 		JButton buttonValidate = new JButton("Validate"); 
 		panel.add(buttonValidate, c);
-		buttonValidate.addActionListener( new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				String uri = textFieldLocation_.getText();
-				if (uri != null && uri.length() > 0) {
-					String doc = DocLoader.convert(uri);
-					if (doc != "") {
-						System.err.println("[DM Validate OK] " + uri);
-					} else {
-						System.err.println("[DM Validate ERROR] " + uri);
-					}
-				}
-			}
-		});
+		buttonValidate.addActionListener( new MainPanelValidateActionListener());
 		
 		// *--- run/pause mode
 		_nextRow(c);
 		_setPos(c, 0, 1, 1);
 		JButton buttonStart = new JButton("Run"); 
 		panel.add(buttonStart, c);
-		buttonStart.addActionListener( new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				labelPauseMode_.setText("Mode: Run");
-				if (eventListener_ != null) {
-					eventListener_.setPauseModeAction(false);
-				} else {
-					System.out.println(e);
-				}
-			}
-		});
+		buttonStart.addActionListener( new MainPanelButtonStartActionListener());
 		
 		// -*--
 		_setPos(c, 1, 1, 1);
 		JButton buttonStop = new JButton("Pause"); 
 		panel.add(buttonStop, c);
-		buttonStop.addActionListener( new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				labelPauseMode_.setText("Mode: Pause");
-				if (eventListener_ != null) {
-					eventListener_.setPauseModeAction(true);
-				} else {
-					System.out.println(e);
-				}
-			}
-		});
+		buttonStop.addActionListener( new MainPanelButtonStopActionListener());
 		
 		// --**
 		_setPos(c, 2, 2);
@@ -746,7 +789,6 @@ public class DialogManagerWindow
 		), c
 		);
 		
-		
 		// applog
 		_nextRow(c);
 		_setPos(c, 0, 4);
@@ -860,61 +902,9 @@ public class DialogManagerWindow
 		return panel;
 	}
 		
-/*	private JPanel _makeHttpServicePanel() {
-		// panel
-		JPanel panel = new JPanel(new GridBagLayout());
-		GridBagConstraints c = _initPos();
-		
-		// ***- location bar
-		_setPos(c, 0, 3, 1);
-		textFieldHttpService_ = new JTextField();
-		textFieldHttpService_.setText("http://localhost:9999/");
-		panel.add(textFieldHttpService_, c);
-		
-		// ---* button 
-		_setPos(c, 3, 1);
-		JButton buttonGo = new JButton("Go"); 
-		panel.add(buttonGo, c);
-		buttonGo.addActionListener( new ActionListener() {
-			public void actionPerformed(ActionEvent e) {
-				try {
-					httpServiceEditorPane_.setPage(textFieldHttpService_.getText());
-				} catch (IOException ex) {
-					ex.printStackTrace();
-				}
-			}
-		});
-
-		_nextRow(c);
-
-		// **** (0-3)
-		_setPos(c, 0, 4, 1, 1);
-		httpServiceEditorPane_ = new JEditorPane();
-		JScrollPane scrollPane = new JScrollPane(httpServiceEditorPane_);
-		httpServiceEditorPane_.setEditable(false);
-		httpServiceEditorPane_.addHyperlinkListener(new HyperlinkListener() {
-			public void hyperlinkUpdate(HyperlinkEvent e) {
-				if (e.getEventType() == HyperlinkEvent.EventType.ACTIVATED) {
-					JEditorPane p = (JEditorPane)e.getSource();
-					try {
-						p.setPage(e.getURL());
-						textFieldHttpService_.setText(e.getURL().toString());
-					} catch (IOException ex) {
-						ex.printStackTrace();
-					}
-				}
-			}
-		});
-		panel.add(scrollPane, c);
-		
-		return panel;
-	}
-*/	
 	public void dispDebuggerEvalResult(String result) {
 		debugEvalResultContent_.append(result + "\n");
 		if (textFieldDebuggerResult_ != null) {
-//			textFieldDebuggerResult_.setText(
-//					debugEvalResultContent_.toString());
 			SwingUtilities.invokeLater(new Runnable() {
 				public void run() {
 					textFieldDebuggerResult_.setText(
@@ -924,37 +914,166 @@ public class DialogManagerWindow
 		}
 	}
 
+	private JPanel _makeLoggerPanel() {
+		JPanel panel = new JPanel(new GridBagLayout());
+		GridBagConstraints c = _initPos();
+		_setPos(c, 0, 0, 1, 1);
+		textFieldLogger_ = new JTextArea();
+		textFieldLogger_.setEditable(false);
+		textFieldLogger_.setRows(1);
+		textFieldLogger_.setLineWrap(true);
+		panel.add(new JScrollPane(textFieldLogger_,
+				ScrollPaneConstants.VERTICAL_SCROLLBAR_ALWAYS,
+				ScrollPaneConstants.HORIZONTAL_SCROLLBAR_NEVER
+		), c
+		);
+		return panel;
+	}
+
+	private JPanel _makeHttpPanel() {
+		JPanel panel = new JPanel(new GridBagLayout());
+		GridBagConstraints c = _initPos();
+		_setPos(c, 0, 0, 1, 1);
+		textFieldHttpLog_ = new JTextArea();
+		textFieldHttpLog_.setEditable(false);
+		textFieldHttpLog_.setRows(1);
+		textFieldHttpLog_.setLineWrap(true);
+		panel.add(new JScrollPane(textFieldHttpLog_,
+				ScrollPaneConstants.VERTICAL_SCROLLBAR_ALWAYS,
+				ScrollPaneConstants.HORIZONTAL_SCROLLBAR_NEVER
+		), c
+		);
+		return panel;
+	}
+	
+	private JPanel _makeViewSrcPanel() {
+		JPanel panel = new JPanel(new GridBagLayout());
+		GridBagConstraints c = _initPos();
+		_setPos(c, 0, 0, 1, 1);
+		textFieldViewSrc_ = new JTextArea();
+		textFieldViewSrc_.setEditable(false);
+		textFieldViewSrc_.setRows(1);
+		textFieldViewSrc_.setLineWrap(true);
+		panel.add(new JScrollPane(textFieldViewSrc_,
+				ScrollPaneConstants.VERTICAL_SCROLLBAR_ALWAYS,
+				ScrollPaneConstants.HORIZONTAL_SCROLLBAR_NEVER
+		), c
+		);
+		return panel;
+	}
+	
+	private JPanel _makeViewGramPanel() {
+		JPanel panel = new JPanel(new GridBagLayout());
+		GridBagConstraints c = _initPos();
+		_setPos(c, 0, 0, 1, 1);
+		textFieldViewGram_ = new JTextArea();
+		textFieldViewGram_.setEditable(false);
+		textFieldViewGram_.setRows(1);
+		textFieldViewGram_.setLineWrap(true);
+		panel.add(new JScrollPane(textFieldViewGram_,
+				ScrollPaneConstants.VERTICAL_SCROLLBAR_ALWAYS,
+				ScrollPaneConstants.HORIZONTAL_SCROLLBAR_NEVER
+		), c
+		);
+		return panel;
+	}
+	
+	private JPanel _makeViewTransPanel() {
+		JPanel panel = new JPanel(new GridBagLayout());
+		GridBagConstraints c = _initPos();
+		_setPos(c, 0, 0, 1, 1);
+		textFieldViewTrans_ = new JTextArea();
+		textFieldViewTrans_.setEditable(false);
+		textFieldViewTrans_.setRows(1);
+		textFieldViewTrans_.setLineWrap(true);
+		panel.add(new JScrollPane(textFieldViewTrans_,
+				ScrollPaneConstants.VERTICAL_SCROLLBAR_ALWAYS,
+				ScrollPaneConstants.HORIZONTAL_SCROLLBAR_NEVER
+		), c
+		);
+		return panel;
+	}
+	
+	private JPanel _makeConfigPanel() {
+		JPanel panel = new JPanel(new GridBagLayout());
+		GridBagConstraints c = _initPos();
+		_setPos(c, 0, 0, 1, 1);
+		textFieldConfig_ = new JTextArea();
+		textFieldConfig_.setEditable(false);
+		textFieldConfig_.setRows(1);
+		textFieldConfig_.setLineWrap(true);
+		panel.add(new JScrollPane(textFieldConfig_,
+				ScrollPaneConstants.VERTICAL_SCROLLBAR_ALWAYS,
+				ScrollPaneConstants.HORIZONTAL_SCROLLBAR_NEVER
+		), c
+		);
+		
+		String config = Property.getConfigStrings();
+		textFieldConfig_.setText(config);
+		
+		return panel;
+	}
+	
 	public DialogManagerWindow() {
 		applogContent_ = new StringBuffer();
 		recogContent_  = new StringBuffer();
 		stateContent_ = new StringBuffer();
 		debugEvalResultContent_ = new StringBuffer();
-		currDirPath_ = Property.getAsStr("user.dir", "/") + "/../";
-		currDirPath_ = "file:" + Util.replaceAll(currDirPath_, "\\", "/");
+		currLocalDirPath_ = Property.getAsStr("user.dir", "/");
+		currLocalDirPath_ += Property.getAsStr("user.dir.suffix", "/files/");
+		currLocalDirPath_ = "file:" + Util.replaceAll(currLocalDirPath_, "\\", "/");
+		
 		if ( Property.getAsBoolean("ShowWindow", true)) {
 			try {
-				_makeWindow();
+				_setLookAndFeel();
+				int w = Property.getAsInt("DM.WindowWidth", 640);
+				int h = Property.getAsInt("DM.WindowHeight", 480);
+				_makeWindow(w, h);
 			} catch(Exception e) { 
 				System.out.println(e); 
 			}
 		}
 	}
 	
-	
+	@SuppressWarnings("unchecked")
+	private void _setLookAndFeel() {
+		final String metal   = "javax.swing.plaf.metal.MetalLookAndFeel";
+		final String mac     = "com.sun.java.swing.plaf.mac.MacLookAndFeel";
+		final String motif   = "com.sun.java.swing.plaf.motif.MotifLookAndFeel";
+		final String windows = "com.sun.java.swing.plaf.windows.WindowsLookAndFeel";
+		final String gtk     = "com.sun.java.swing.plaf.gtk.GTKLookAndFeel";
+		String lafname = metal;
+		if (Util.isWindows()) {
+			lafname = windows;
+		}
+		try {
+			Class lnfClass = Class.forName(windows);
+			LookAndFeel newLAF = (LookAndFeel) (lnfClass.newInstance());
+			if (newLAF.isSupportedLookAndFeel()) {
+				try {
+					UIManager.setLookAndFeel(newLAF);
+					//SwingUtilities.updateComponentTreeUI(this);
+				} catch (Exception e) {
+					e.printStackTrace();
+				}
+			}
+		} catch (Exception e) {
+			e.printStackTrace();
+		}
+	}
+
 	public void documentLocationChanged(String text) {
 		if (textFieldLocation_ != null) {
 			textFieldLocation_.setText(text);
 		}
 	}
 	
-	
 	public void outputVoiceStarted(String text) {
 		if (textFieldSpeaking_ != null) {
 			textFieldSpeaking_.setText(Util.removeTags(text));
 		}
 	}
 	
-	
 	public void dispApplog(String text) {
 		if (applogContent_ != null) {
 			applogContent_.insert(0, text + "\n");
@@ -997,27 +1116,51 @@ public class DialogManagerWindow
 	}
 	
 	public void srcFileUpdated(String text) {
-		srcFile_ = text;
-		if (viewSrcPane_ != null) {
-			viewSrcPane_.setText(srcFile_);
+//		srcFile_ = text;
+//		if (viewSrcPane_ != null) {
+//			viewSrcPane_.setText(srcFile_);
+//		}
+		if (textFieldViewSrc_ != null) {
+			textFieldViewSrc_.setText(text);
 		}
 	}
 	
-	
 	public void translatedFileUpdated(String text) {
-		translatedFile_ = text;
-		if (viewTranslatedPane_ != null) {
-			viewTranslatedPane_.setText(translatedFile_);
+//		translatedFile_ = text;
+//		if (viewTranslatedPane_ != null) {
+//			viewTranslatedPane_.setText(translatedFile_);
+//		}
+		if (textFieldViewTrans_ != null) {
+			textFieldViewTrans_.setText(text);
 		}
 	}
 	
 	public void grammarFileUpdated(String text) {
-		grammarFile_ = text;
-		if (viewGrammarPane_ != null) {
-			viewGrammarPane_.setText(grammarFile_);
+//		grammarFile_ = text;
+//		if (viewGrammarPane_ != null) {
+//			viewGrammarPane_.setText(grammarFile_);
+//		}
+		if (textFieldViewGram_ != null) {
+			textFieldViewGram_.setText(text);
 		}
 	}
 	
+	@Override
+	public void addNetUtilEvent(String msg) {
+		if (textFieldHttpLog_ != null) {
+			httpLogText_ += msg + "\n";
+			textFieldHttpLog_.setText(httpLogText_);
+		}
+	}
+
+	@Override
+	public void addLoggerEvent(String msg) {
+		if (textFieldLogger_ != null) {
+			loggerText_ = msg + "\n" + loggerText_;
+			textFieldLogger_.setText(loggerText_);
+		}
+	}
+
 	public static void main(String args[]) throws Exception {
 		DialogManagerWindow w = new DialogManagerWindow();
 		w.dispApplog("abc日本語です。");
@@ -1025,10 +1168,6 @@ public class DialogManagerWindow
 		w.dispApplog("os.arch=" + System.getProperty("os.arch"));
 		w.dispApplog("os.name=" + System.getProperty("os.name"));
 		w.dispApplog("user.dir=" + System.getProperty("user.dir"));
-		// java.io.tmpdir=/tmp
-		// os.arch=i386
-		// os.name=Linux
-		// user.dir=/home/nishi/local/galatea-devel/DM/phoenix
 		
 		for (int i = 0; ; i++) {
 			String s = "test" + i;
