@@ -3,7 +3,7 @@
  * (c)2003-2004 Takuya NISHIMOTO (nishi@hil.t.u-tokyo.ac.jp)
  * Based on Phoenix By Takuya NISHIMOTO and Mitsuhiro KIZU
  *
- * $Id: VXMLDoc.java,v 1.14 2007/01/15 03:16:37 nishi Exp $
+ * $Id: VXMLDoc.java,v 1.17 2008/02/14 02:00:07 nishi Exp $
  */
 
 package galatea.document;
@@ -17,11 +17,14 @@ import galatea.command.GotoCommand;
 import galatea.command.SetNextCommand;
 import galatea.command.StopOutputCommand;
 import galatea.grammar.GrammarUtil;
+import galatea.httpclient.NetUtil;
+import galatea.logger.Logger;
 import galatea.outitem.AudioOutItem;
 import galatea.outitem.BreakOutItem;
 import galatea.outitem.GrammarOutItem;
 import galatea.outitem.LogOutItem;
 import galatea.outitem.NativeOutItem;
+import galatea.outitem.OutItem;
 import galatea.outitem.VoiceOutItem;
 import galatea.relaxer.vxml20.IVxmlFormChoice;
 import galatea.relaxer.vxml20.IVxmlVxmlChoice;
@@ -92,14 +95,13 @@ import galatea.relaxer.vxml20.VxmlVar;
 import galatea.relaxer.vxml20.VxmlVoice;
 import galatea.relaxer.vxml20.VxmlVxml;
 import galatea.util.HashArray;
-import galatea.util.Logger;
-import galatea.util.NetUtil;
 import galatea.util.Property;
 import galatea.util.Util;
 
 import java.util.ArrayList;
 import java.util.Stack;
 
+
 import org.w3c.dom.Element;
 
 
@@ -112,8 +114,8 @@ public class VXMLDoc implements IAbstractDoc // VoiceXML形式
 	
 	private StateMap stateMap_ = null;
 	
-	private ArrayList docErrors_ = null;
-	private ArrayList docWarnings_ = null;
+	private ArrayList<DocError> docErrors_ = null;
+	private ArrayList<DocWarning> docWarnings_ = null;
 	
 	private double promptTimeout_;
 	private int unique_ = 0;
@@ -203,7 +205,7 @@ public class VXMLDoc implements IAbstractDoc // VoiceXML形式
 		/**
 		 * object tree: VxmlXXX Object
 		 */
-		private Stack visitorStack_ = new Stack(); 
+		private Stack<Object> visitorStack_ = new Stack<Object>(); 
 		
 		/**
 		 * prompt selection
@@ -211,23 +213,23 @@ public class VXMLDoc implements IAbstractDoc // VoiceXML形式
 		protected class Prompt {
 			public int count = 1;
 			public String cond = null;
-			public ArrayList commands = null;
+			public ArrayList<Command> commands = null;
 		}
 		/**
 		 * ArrayList of Prompt
 		 */
-		private ArrayList promptList_ = null; 
+		private ArrayList<Visitor.Prompt> promptList_ = null; 
 		
 		/**
 		 * ArrayList of Command
 		 */
 		protected class Commands
 		{
-			private ArrayList cmdvec_ = null;
+			private ArrayList<Command> cmdvec_ = null;
 			
 			public void setupCommands() {
 				if ( cmdvec_ == null ) {
-					cmdvec_ = new ArrayList();
+					cmdvec_ = new ArrayList<Command>();
 				} else {
 					String str = "";
 					for (int i = 0, n = cmdvec_.size(); i < n; i++) {
@@ -256,14 +258,14 @@ public class VXMLDoc implements IAbstractDoc // VoiceXML形式
 				}
 			}
 			
-			public ArrayList getCommands() {
+			public ArrayList<Command> getCommands() {
 				return cmdvec_;
 			}
 			
 			/**
 			 * cmdvec_をvで上書きする（prompt乗っ取り）
 			 */
-			public void setCommands(ArrayList v) {
+			public void setCommands(ArrayList<Command> v) {
 				if (cmdvec_ != null && cmdvec_.size() > 0) {
 					String str = "";
 					for (int i = 0, n = cmdvec_.size(); i < n; i++) {
@@ -294,7 +296,7 @@ public class VXMLDoc implements IAbstractDoc // VoiceXML形式
 		 */
 		protected class ExecContents
 		{
-			private Stack execContentsStack_ = new Stack();
+			private Stack<Command> execContentsStack_ = new Stack<Command>();
 			private int stackCount_ = 0;
 			
 			/**
@@ -305,11 +307,11 @@ public class VXMLDoc implements IAbstractDoc // VoiceXML形式
 				stackCount_++;
 				dbg.print("setupExecContent: "+ stackCount_ + " " + cond);
 				// create context
-				ArrayList c = new ArrayList();
+				ArrayList<Command> c = new ArrayList<Command>();
 				CompositeCommand co = new CompositeCommand(c, cond);
 				
 				// save context
-				execContentsStack_.push((Object)co);
+				execContentsStack_.push(co);
 			}
 			
 			private void setupExecContent() {
@@ -549,11 +551,12 @@ public class VXMLDoc implements IAbstractDoc // VoiceXML形式
 				String id = "";
 				if (root != null && root.startsWith("#")) {
 					
-					if (visitorStack_.peek() instanceof VxmlForm) {
-						id = dialog_.getName() + "_" + root.replaceAll("#", "");
-					} else if (visitorStack_.peek() instanceof VxmlField) {
-						id = dialog_.getName() + "_" + dialog_.getItemName() + "_" + root.replaceAll("#", "");
-					}
+//					if (visitorStack_.peek() instanceof VxmlForm) {
+//						id = dialog_.getName() + "_" + root.replaceAll("#", "");
+//					} else if (visitorStack_.peek() instanceof VxmlField) {
+//						id = dialog_.getName() + "_" + dialog_.getItemName() + "_" + root.replaceAll("#", "");
+//					}
+					id = _getUniqueId("rule");
 					
 				} else {
 					// assert(false)
@@ -661,12 +664,12 @@ public class VXMLDoc implements IAbstractDoc // VoiceXML形式
 			}
 			stateMap_.addScriptCommand(form, sc);
 			
-			ArrayList items = new ArrayList();
+			ArrayList<OutItem> items = new ArrayList<OutItem>();
 			String s;
 			s = "'to @SIM set DialogName = " + dialog_.getName() + "'";
-			items.add((Object)new NativeOutItem(s));
+			items.add(new NativeOutItem(s));
 			s = "'to @SIM set SlotAlias = RESET'";
-			items.add((Object)new NativeOutItem(s));
+			items.add(new NativeOutItem(s));
 			for ( int i = 0; i < formItems_.size(); i++ ) {
 				Object fi = formItems_.get(i);
 				if ( fi instanceof VxmlField ) {
@@ -674,7 +677,7 @@ public class VXMLDoc implements IAbstractDoc // VoiceXML形式
 					if (f.getSlot() != null) {
 						String name = formItems_.getKey(i);
 						s = "'to @SIM set SlotAlias = " + f.getSlot()+ " " + name + "'";
-						items.add((Object)new NativeOutItem(s));
+						items.add(new NativeOutItem(s));
 					}
 				}
 			}
@@ -977,7 +980,7 @@ public class VXMLDoc implements IAbstractDoc // VoiceXML形式
 			_makeInputEventHandler(field);
 			
 			// initialize promptList_
-			promptList_ = new ArrayList();
+			promptList_ = new ArrayList<Visitor.Prompt>();
 			
 			visitorStack_.push(vxmlField);
 			return true;
@@ -1001,7 +1004,7 @@ public class VXMLDoc implements IAbstractDoc // VoiceXML形式
 			+ dialog_.getItemName() + "$" + ".promptcond";
 			//promptCond = "true"; // debug
 			CompositeCommand promptCmd = new CompositeCommand
-			(new ArrayList(), promptCond);
+			(new ArrayList<Command>(), promptCond);
 			
 			if (promptList_ == null) {
 				return; 
@@ -1139,7 +1142,7 @@ public class VXMLDoc implements IAbstractDoc // VoiceXML形式
 			visitorStack_.push(vxmlMenu);
 			
 			// initialize promptList_
-			promptList_ = new ArrayList();
+			promptList_ = new ArrayList<Visitor.Prompt>();
 			_resetDialogProperty();
 
 			String dialogName;
@@ -1349,7 +1352,7 @@ public class VXMLDoc implements IAbstractDoc // VoiceXML形式
 				currPromptCond_ = vxmlPrompt.getCond();
 				currPromptCount_ = vxmlPrompt.getCount();
 				
-				commands_.setCommands(new ArrayList());
+				commands_.setCommands(new ArrayList<Command>());
 				
 				execContents_.setupExecContent();
 			}
@@ -1614,7 +1617,7 @@ public class VXMLDoc implements IAbstractDoc // VoiceXML形式
 				execContents_.appendExecContent(c);
 			} else {
 				String eval = "'" + resolveAdrs(next) + "'";
-				Command c = (Command)( new EndCommand(eval, "true") );
+				Command c = (Command)( new EndCommand(eval) );
 				execContents_.appendExecContent(c);
 			}
 			
@@ -2039,6 +2042,12 @@ public class VXMLDoc implements IAbstractDoc // VoiceXML形式
 		}
 		
 		public boolean enter(VxmlSubmit e) {
+			String post = "";
+			boolean isPost = false;
+			if (e.getMethod() != null && e.getMethod().toLowerCase().equals("post") ) {
+				isPost = true;
+			}
+			
 			String script = "";
 			if (e.getNext() != null) {
 				script = "'" + resolveAdrs(Util.removeSpaces(e.getNext())) + "'";
@@ -2049,34 +2058,61 @@ public class VXMLDoc implements IAbstractDoc // VoiceXML形式
 				return false;
 			}
 			
-			String names[];
-			String namelist = e.getNamelist();
-			if (namelist == null) {
-				for (int i = 0; i < submitItems_.size(); i++) {
-//					String name = submitItems_.getKey(i);
-					if ( i == 0 ) {
-						script += "+'?'";
-					} else {
-						script += "+'&'";
+			if (isPost) {
+				// do POST method
+				String names[];
+				String namelist = e.getNamelist();
+				if (namelist == null) {
+					for (int i = 0; i < submitItems_.size(); i++) {
+						if ( i == 0 ) {
+							//script += "+'?'";
+						} else {
+							post += "+'&'";
+						}
+						post += "'" + submitItems_.getKey(i) + "='+" + submitItems_.getKey(i);
+					}
+				} else {
+					names = namelist.split(" ");
+					for (int i = 0; i < names.length; i++) {
+						if ( i == 0 ) {
+							// script += "+'?'";
+						} else {
+							post += "+'&'";
+						}
+						post += "'" + names[i] + "='+" + names[i];
 					}
-					script += "+'" + submitItems_.getKey(i) + "='+" + submitItems_.getKey(i);
 				}
+				post = _getEvalWith(post, dialog_.getName());
 			} else {
-				names = namelist.split(" ");
-				for (int i = 0; i < names.length; i++) {
-					if ( i == 0 ) {
-						script += "+'?'";
-					} else {
-						script += "+'&'";
+				// do GET method
+				String names[];
+				String namelist = e.getNamelist();
+				if (namelist == null) {
+					for (int i = 0; i < submitItems_.size(); i++) {
+						if ( i == 0 ) {
+							script += "+'?'";
+						} else {
+							script += "+'&'";
+						}
+						script += "+'" + submitItems_.getKey(i) + "='+" + submitItems_.getKey(i);
+					}
+				} else {
+					names = namelist.split(" ");
+					for (int i = 0; i < names.length; i++) {
+						if ( i == 0 ) {
+							script += "+'?'";
+						} else {
+							script += "+'&'";
+						}
+						script += "+'" + names[i] + "='+" + names[i];
 					}
-					script += "+'" + names[i] + "='+" + names[i];
 				}
+				script += ";";
 			}
-			script += ";";
 			textBuf_.flushSpeak();
 			//
 			String eval = _getEvalWith(script, dialog_.getName());
-			Command c = (Command)( new EndCommand(eval, "true") );
+			Command c = (Command)( new EndCommand(eval, "true", false, post) );
 			execContents_.appendExecContent(c);
 			//
 			textBuf_.setupSpeak();
@@ -2536,8 +2572,8 @@ public class VXMLDoc implements IAbstractDoc // VoiceXML形式
 	{
 		promptTimeout_ = Property.getAsDouble("VXMLDoc.PromptTimeout", 10.0);
 		
-		docErrors_ = new ArrayList();
-		docWarnings_ = new ArrayList();
+		docErrors_ = new ArrayList<DocError>();
+		docWarnings_ = new ArrayList<DocWarning>();
 		
 		if (VxmlVxml.isMatch(e) == false) {
 			throw new DocError("Not a valid <vxml> document: " + adrs + "#" + dialog);
