@@ -2,11 +2,11 @@
  * Galatea Dialog Manager:
  * (c)2004 Takuya NISHIMOTO (nishi@hil.t.u-tokyo.ac.jp)
  *
- * $Id: OutputEventQueueManager.java,v 1.1 2006/11/20 01:13:35 nishi Exp $
+ * $Id: OutputEventQueueManager.java,v 1.3 2008/02/14 02:00:07 nishi Exp $
  */
 package galatea.io;
 
-import galatea.util.Logger;
+import galatea.logger.Logger;
 
 import java.util.*;
 
@@ -14,11 +14,11 @@ public class OutputEventQueueManager
 {
 	private Logger dbg = new Logger("EQM", 0);
 	
-	private ArrayList queue_; // ArrayList<DeviceEvent>
+	private ArrayList<DeviceEvent> queue_; // ArrayList<DeviceEvent>
 	
 	public OutputEventQueueManager()
 	{
-		queue_ = new ArrayList();
+		queue_ = new ArrayList<DeviceEvent>();
 	}
 	
 	public synchronized void discard()
@@ -28,7 +28,7 @@ public class OutputEventQueueManager
 	
 	public synchronized void enqueue(DeviceEvent o)
 	{
-		queue_.add((Object)o);
+		queue_.add(o);
 		dbg.print("EQM: added " + o.getClass().getName() 
 				+ ", total:" + queue_.size() );
 	}
