@@ -2,7 +2,7 @@
  * Galatea Dialog Manager:
  * (c)2003 Takuya NISHIMOTO (nishi@hil.t.u-tokyo.ac.jp)
  *
- * $Id: GrammarOutItem.java,v 1.5 2007/01/15 03:16:37 nishi Exp $
+ * $Id: GrammarOutItem.java,v 1.7 2008/02/14 02:00:07 nishi Exp $
  */
 
 package galatea.outitem;
@@ -22,22 +22,9 @@ public class GrammarOutItem extends OutItem
 		isImportant_ = true;
 		grammar_ = grammar;
 		name_ = name;
-		dir_ = Property.getAsStr("GrammarWorkDir", "/tmp");
-		// TODO switch property
-		if (Util.isWindows()) {
-			dir_ = "c:" + dir_;
-		}
+		dir_ = Property.getForPlatformAsStr("Grammar.WorkDir", "/tmp");
 	}
 	
-//	public GrammarOutItem(String grammar, String name, String dir)
-//	{
-//		isInstant_ = false;
-//		isImportant_ = true;
-//		grammar_ = grammar;
-//		name_ = name;
-//		dir_ = dir;
-//	}
-	
 	public String toString()
 	{
 		return "<grammarout name=\"" + name_ + "\" dir=\"" + dir_ + "\"><![CDATA[" + grammar_ + "]]></grammarout>";
