@@ -3,7 +3,7 @@
  *
  * (c)2003-2004 Takuya NISHIMOTO (nishi@hil.t.u-tokyo.ac.jp)
  *
- * $Id: GalateaGlobal.java,v 1.1 2006/10/26 10:35:24 nishi Exp $
+ * $Id: GalateaGlobal.java,v 1.4 2008/02/15 03:26:00 nishi Exp $
  *
  * Wrappar class for Mozilla Rhino / shell Global class
  */
@@ -13,13 +13,10 @@ package galatea.scripting;
 import org.mozilla.javascript.*;
 import org.mozilla.javascript.tools.shell.*;
 
-public class GalateaGlobal extends Global 
-{
-    public GalateaGlobal(Context cx)
-    {
+public class GalateaGlobal extends Global {
+    public GalateaGlobal(Context cx) {
         super(cx);
     }
-
 }
 
 
