@@ -2,7 +2,7 @@
  * Galatea Dialog Manager:
  * (c)2004 Takuya NISHIMOTO (nishi@hil.t.u-tokyo.ac.jp)
  *
- * $Id: StrQueue.java,v 1.3 2006/11/24 02:09:14 nishi Exp $
+ * $Id: StrQueue.java,v 1.4 2008/02/12 06:15:29 nishi Exp $
  */
 package galatea.util;
 
@@ -10,17 +10,17 @@ import java.util.ArrayList;
 
 public class StrQueue
 {
-	private ArrayList queue_ = null;
+	private ArrayList<String> queue_ = null;
 	
 	public StrQueue()
 	{
-		queue_ = new ArrayList();
+		queue_ = new ArrayList<String>();
 	}
 	
 	public void enqueue(String str)
 	{
 		synchronized(queue_) {
-			queue_.add((Object)str);
+			queue_.add(str);
 		}
 	}
 	
